@@ -101,6 +101,9 @@ def read_rows_from_batch(query_columns_description: list, dis: DataInputStream)
         if is_row_present:
             row = read_values_from_array(query_columns_description, dis)
             rows.append(row)
+        #   if rows become 1000, break it
+            if len(rows) == 1000:
+                break
         is_row_present = dis.read_byte()
 
     return rows
