@@ -331,7 +331,6 @@ class Cursor(common.DBAPICursor):
         return self._fetch_all()
 
     def fetchone(self):
-
         _logger.info("fetching one")
         if len(self._batch) == 0:
             self.fetch_batch()
@@ -397,7 +396,7 @@ if __name__ == '__main__':
                          ssl_cert=None,
                          thrift_transport=None)
     cursor = Cursor(connection)
-    cursor.execute("SELECT sr_returned_date_sk,sr_return_time_sk,sr_item_sk,sr_customer_sk,sr_cdemo_sk,sr_hdemo_sk,sr_addr_sk FROM store_returns WHERE sr_hdemo_sk >= 2000 AND sr_hdemo_sk < 2000 + 1;")
+    cursor.execute("SELECT c_first_name FROM store_returns AS sr, customer AS c WHERE c.c_customer_sk = sr.sr_customer_sk AND c.c_first_name = 'Susan' ORDER BY sr_returned_date_sk;")
     bdata = cursor.fetchone()
     try:
         while bdata:
